# loading R packages

library(openair)
library(RColorBrewer)

# reading hourly database

mydata<-read.csv2("Database.csv",header=TRUE)

mydata$date<-as.POSIXct(strptime(mydata$date, format = "%d-%m-%Y %H:%M"))

# first sanity check...

summary(mydata)


# some meteorological sanity checks...

png('TimeSeries_ws_1h_Santiago.png', width = 12 * 600, height = 6 * 600, res = 600)
timePlot(mydata, pollutant = 'ws', main='Santiago, march 2020 - january 2021', 
         lwd=1, lty=1,ylab=expression("m/s"))
dev.off()

png('TimeVariation_ws_1h_Santiago.png', width = 12 * 600, height = 6 * 600, res = 600)
timeVariation(mydata, pollutant = 'ws', main='Santiago, march 2020 - january 2021',  
              lwd=1, lty=1,ylab=expression("m/s"))
dev.off()

png('TimeSeries_temp_1h_Santiago.png', width = 12 * 600, height = 6 * 600, res = 600)
timePlot(mydata, pollutant = 'temp', main='Santiago, march 2020 - january 2021', 
         lwd=1, lty=1,ylab=expression("C"))
dev.off()

png('TimeVariation_temp_1h_Santiago.png', width = 12 * 600, height = 6 * 600, res = 600)
timeVariation(mydata, pollutant = 'temp', main='Santiago, march 2020 - january 2021',  
              lwd=1, lty=1,ylab=expression("C"))
dev.off()

png("RoseWind_Santiago.png", width = 6 * 600, height = 6 * 600, res = 600)
windRose(mydata, pollutant="ws", main="Santiago 2020-03 2021-01",type="season", 
hemisphere="southern", paddle=FALSE, breaks=c(0,1,2,3))
dev.off()

png("RoseWind_Santiago_v2.png", width = 8 * 600, height = 12 * 600, res = 600)
windRose(mydata, pollutant="ws", main="Santiago 2020-03 2021-01",type="hour", 
paddle=FALSE, breaks=c(0,1,2,3))
dev.off()


# generating cartesian wind components

mydata$u <- -mydata$ws*sin(mydata$wd*2*pi/360)

mydata$v <- -mydata$ws*cos(mydata$wd*2*pi/360)

# checking normality of BC fractions

hist(mydata$BCff)
hist(mydata$BCwb)

# logtransform to get near normal pdfs

mydata$lnBCff<-log(mydata$BCff)
mydata$lnBCwb<-log(mydata$BCwb)

# checking histograms - another sanity check...

hist(mydata$lnBCff)
hist(mydata$lnBCwb)


# generating the complete data set (it will usually have missing/invalid data)

set1 <- subset(mydata, select=c(date,BCff,BCwb,lnBCff,lnBCwb,temp,u,v,pres,ws,wd))


# saving the complete set for post-processing 

write.csv(set1,"set1.csv",row.names=FALSE)


# getting rid of anomalous data (cf. Appendix A, consequence of defining Angstrom exponents as percentiles)

set2<-subset(set1,lnBCff>=-3.0)   # this threshold is data dependent... see the histogram of your own data before choosing it

summary(set2)

# removing missing entries 

set2<-na.omit(set2)

summary(set2)   # yet another sanity check...

write.csv(set2,"set2.csv",row.names=FALSE)

# this will be the working file for fuzzy clustering processing



