# reading cluster analysis results

library(openair)
library(lattice)
library(RColorBrewer)


#Reading a 4-cluster solution (plus a noisy cluster)

mydata_1<-read.csv("set1.csv")
mydata_1$date<-as.POSIXct(strptime(mydata_1$date, format = "%Y-%m-%d %H:%M",tz="Etc/GMT+4"))
summary(mydata_1)  # sanity check...

mydata_2<-read.csv("set2.csv")
mydata_2$date<-as.POSIXct(strptime(mydata_2$date, format = "%Y-%m-%d %H:%M",tz="Etc/GMT+4"))
summary(mydata_2)  # sanity check...

mydata_3<-read.csv("mydataff_4C.csv")
mydata_3$date<-mydata_2$date
names(mydata_3)[1]<-'Clus.1'
names(mydata_3)[2]<-'Clus.2'
names(mydata_3)[3]<-'Clus.3'
names(mydata_3)[4]<-'Clus.4'

summary(mydata_3)  # sanity check...


# joining data sets

mydata<- merge(mydata_1, mydata_3, by="date", all = TRUE)

# defining cluster contributions

mydata$BCff_1<-mydata$BCff*mydata$Clus.1
mydata$BCff_2<-mydata$BCff*mydata$Clus.2
mydata$BCff_3<-mydata$BCff*mydata$Clus.3
mydata$BCff_4<-mydata$BCff*mydata$Clus.4
mydata$BCff_5<-mydata$BCff*(1-(mydata$Clus.1+mydata$Clus.2+mydata$Clus.3+mydata$Clus.4))

summary(mydata)  # sanity check

# saving a backup copy...

write.csv(mydata,"mydata.csv",row.names=FALSE) 


# source contributions and time variability plots

png("TimeVariation_4C+1_mydata__BCff.png", width = 11 * 600, height = 7 * 600, res = 600)
timeVariation(mydata, pollutant=c("BCff_1","BCff_2","BCff_3","BCff_4","BCff_5"), 
main="Santiago BC", cols = "Set1",lwd = 3, ylab="BCff (ng/m3)",key.columns = 6)
dev.off()


png("Timeplot_mydata_BCff_4C+1_h.png", width = 11 * 600, height = 6 * 600, res = 600)
timePlot(mydata, pollutant=c("BCff_1","BCff_2","BCff_3","BCff_4","BCff_5"),date.format = "%m/%y", 
group = FALSE, xlab="month/year",ylab="hourly BC (ng/m3)",
y.relation="free",key=FALSE,main="Santiago 2020")
dev.off()

png("Timeplot_mydata__BCff_4C+1_day.png", width = 11 * 600, height = 6 * 600, res = 600)
timePlot(mydata, pollutant=c("BCff_1","BCff_2","BCff_3","BCff_4","BCff_5"),date.format = "%m/%y", 
group = FALSE, xlab="month/year",ylab="daily BC (ng/m3)",avg.time = "day",
y.relation="free",key=FALSE,main="Santiago 2020")
dev.off()


#polar plots BCff wrt (ws, wd)
P5<-polarPlot(mydata, pollutant="BCff_5",main="Cluster 5 BCff")
P4<-polarPlot(mydata, pollutant="BCff_4",main="Cluster 4 BCff")
P3<-polarPlot(mydata, pollutant="BCff_3",main="Cluster 3 BCff")
P2<-polarPlot(mydata, pollutant="BCff_2",main="Cluster 2 BCff")
P1<-polarPlot(mydata, pollutant="BCff_1",main="Cluster 1 BCff")

png("Polar_BCff_mydata_4C+1_ws_wd.png", width = 12 * 600, height = 7 * 600, res = 600)
print(P1, position = c(0, 0.5, 0.33, 1), more = TRUE)
print(P2, position = c(0.33, 0.5, 0.66, 1), more = TRUE)
print(P3, position = c(0.66, 0.5, 1, 1), more = TRUE)
print(P4, position = c(0, 0, 0.33, 0.5), more = TRUE)
print(P5, position = c(0.33, 0, 0.66, 0.5))
dev.off()

# polar plots BCff wrt (temp, wd)
P5<-polarPlot(mydata, pollutant="BCff_5", x="temp", main="Cluster 5 BCff")
P4<-polarPlot(mydata, pollutant="BCff_4", x="temp", main="Cluster 4 BCff")
P3<-polarPlot(mydata, pollutant="BCff_3", x="temp", main="Cluster 3 BCff")
P2<-polarPlot(mydata, pollutant="BCff_2", x="temp", main="Cluster 2 BCff")
P1<-polarPlot(mydata, pollutant="BCff_1", x="temp", main="Cluster 1 BCff")

png("Polar_BCff_mydata_4C+1_temp_wd.png", width = 12 * 600, height = 7 * 600, res = 600)
print(P1, position = c(0, 0.5, 0.33, 1), more = TRUE)
print(P2, position = c(0.33, 0.5, 0.66, 1), more = TRUE)
print(P3, position = c(0.66, 0.5, 1, 1), more = TRUE)
print(P4, position = c(0, 0, 0.33, 0.5), more = TRUE)
print(P5, position = c(0.33, 0, 0.66, 0.5))
dev.off()

# polar plots BCff wrt (pres, wd)
P5<-polarPlot(mydata, pollutant="BCff_5", x="pres", main="Cluster 5 BCff")
P4<-polarPlot(mydata, pollutant="BCff_4", x="pres", main="Cluster 4 BCff")
P3<-polarPlot(mydata, pollutant="BCff_3", x="pres", main="Cluster 3 BCff")
P2<-polarPlot(mydata, pollutant="BCff_2", x="pres", main="Cluster 2 BCff")
P1<-polarPlot(mydata, pollutant="BCff_1", x="pres", main="Cluster 1 BCff")

png("Polar_BCff_mydata_4C+1_pres_wd.png", width = 12 * 600, height = 7 * 600, res = 600)
print(P1, position = c(0, 0.5, 0.33, 1), more = TRUE)
print(P2, position = c(0.33, 0.5, 0.66, 1), more = TRUE)
print(P3, position = c(0.66, 0.5, 1, 1), more = TRUE)
print(P4, position = c(0, 0, 0.33, 0.5), more = TRUE)
print(P5, position = c(0.33, 0, 0.66, 0.5))
dev.off()










