# reading cluster analysis results (fclust fuzzy toolbox en R)

library(openair)
library(lattice)
library(RColorBrewer)

#reading a 3-cluster solution (plus a noisy cluster) 

mydata_1<-read.csv("set1.csv")
mydata_1$date<-as.POSIXct(strptime(mydata_1$date, format = "%Y-%m-%d %H:%M",tz="Etc/GMT+4"))
summary(mydata_1)  # sanity check...

mydata_2<-read.csv("set2.csv")
mydata_2$date<-as.POSIXct(strptime(mydata_2$date, format = "%Y-%m-%d %H:%M",tz="Etc/GMT+4"))
summary(mydata_2)  # sanity check...

mydata_3<-read.csv("mydatawb_3C.csv")
mydata_3$date<-mydata_2$date
names(mydata_3)[1]<-'Clus.1'
names(mydata_3)[2]<-'Clus.2'
names(mydata_3)[3]<-'Clus.3'

summary(mydata_3)  # sanity check.. 

# joining both data sets

mydata <- merge(mydata_1, mydata_3, by="date", all = TRUE)

mydata$BCwb_1<-mydata$BCwb*mydata$Clus.1
mydata$BCwb_2<-mydata$BCwb*mydata$Clus.2
mydata$BCwb_3<-mydata$BCwb*mydata$Clus.3
mydata$BCwb_4<-mydata$BCwb*(1-(mydata$Clus.1+mydata$Clus.2+mydata$Clus.3))

summary(mydata) # sanity check...

# saving a copy on disk

write.csv(mydata,"mydatawb_3C+1_2020.csv",row.names=FALSE) 


# source contributions and time variability plots

png("TimeVariation_3C+1_mydata_BCwb.png", width = 11 * 600, height = 7 * 600, res = 600)
timeVariation(mydata, pollutant=c("BCwb_1","BCwb_2","BCwb_3","BCwb_4"), 
main="Santiago BC 2020", cols = "Set1",lwd = 3, ylab="BCwb (ng/m3)",key.columns = 6)
dev.off()


png("Timeplot_mydata_BCwb_3C+1_h.png", width = 11 * 600, height = 6 * 600, res = 600)
timePlot(mydata, pollutant=c("BCwb_1","BCwb_2","BCwb_3","BCwb_4"),date.format = "%m/%y", 
group = FALSE, xlab="month/year",ylab="hourly BC (ng/m3)",
y.relation="free",key=FALSE,main="Santiago 2020")
dev.off()

png("Timeplot_mydata_BCwb_3C+1_day.png", width = 11 * 600, height = 6 * 600, res = 600)
timePlot(mydata, pollutant=c("BCwb_1","BCwb_2","BCwb_3","BCwb_4"),date.format = "%m/%y", 
group = FALSE, xlab="month/year",ylab="daily BC (ng/m3)",avg.time = "day",
y.relation="free",key=FALSE,main="Santiago 2020")
dev.off()


#polar plots BCwb wrt (ws, wd)
P4<-polarPlot(mydata, pollutant="BCwb_4",main="Cluster 4 BCwb")
P3<-polarPlot(mydata, pollutant="BCwb_3",main="Cluster 3 BCwb")
P2<-polarPlot(mydata, pollutant="BCwb_2",main="Cluster 2 BCwb")
P1<-polarPlot(mydata, pollutant="BCwb_1",main="Cluster 1 BCwb")

png("Polar_BCwb_mydata_3C+1_ws_wd.png", width = 12 * 600, height = 7 * 600, res = 600)
print(P1, position = c(0, 0.5, 0.5, 1), more = TRUE)
print(P2, position = c(0.5, 0.5, 1, 1), more = TRUE)
print(P3, position = c(0, 0, 0.5, 0.5), more = TRUE)
print(P4, position = c(0.5, 0, 1, 0.5))
dev.off()

# polar plots BCwb wrt (temp, wd)
P4<-polarPlot(mydata, pollutant="BCwb_4", x="temp", main="Cluster 4 BCwb")
P3<-polarPlot(mydata, pollutant="BCwb_3", x="temp", main="Cluster 3 BCwb")
P2<-polarPlot(mydata, pollutant="BCwb_2", x="temp", main="Cluster 2 BCwb")
P1<-polarPlot(mydata, pollutant="BCwb_1", x="temp", main="Cluster 1 BCwb")

png("Polar_BCwb_mydata_3C+1_temp_wd.png", width = 12 * 600, height = 7 * 600, res = 600)
print(P1, position = c(0, 0.5, 0.5, 1), more = TRUE)
print(P2, position = c(0.5, 0.5, 1, 1), more = TRUE)
print(P3, position = c(0, 0, 0.5, 0.5), more = TRUE)
print(P4, position = c(0.5, 0, 1, 0.5))
dev.off()

# polar plots BCwb wrt (pres, wd)
P4<-polarPlot(mydata, pollutant="BCwb_4", x="pres", main="Cluster 4 BCwb")
P3<-polarPlot(mydata, pollutant="BCwb_3", x="pres", main="Cluster 3 BCwb")
P2<-polarPlot(mydata, pollutant="BCwb_2", x="pres", main="Cluster 2 BCwb")
P1<-polarPlot(mydata, pollutant="BCwb_1", x="pres", main="Cluster 1 BCwb")

png("Polar_BCwb_mydata_3C+1_pres_wd.png", width = 12 * 600, height = 7 * 600, res = 600)
print(P1, position = c(0, 0.5, 0.5, 1), more = TRUE)
print(P2, position = c(0.5, 0.5, 1, 1), more = TRUE)
print(P3, position = c(0, 0, 0.5, 0.5), more = TRUE)
print(P4, position = c(0.5, 0, 1, 0.5))
dev.off()



